@@ -14,7 +14,8 @@ def get_directus_client(token, base_url):
         (no trailing slash)
     """
     headers = {
-        'Authorization': f'Bearer {token}'
+        'Authorization': f'Bearer {token}',
+        "Cache-Control": "no-store"
     }
     def directus_client(method, path, parameters=None, url=None, data=None, resource=False):
         _parameters = {**parameters} if parameters else {}
@@ -38,10 +39,10 @@ def get_directus_client(token, base_url):
                                         headers=headers)
                 filter_count = result['meta']['filter_count']
                 results.extend(result['data'])
-                has_more_items = len(results) > filter_count
+                has_more_items = len(results) < filter_count
 
         else:
-            response = common_client(method, base_url, path, parameters, url, headers, data)
+            response = common_client(method, base_url, path, _parameters, url, headers, data)
             if response:
                 results = response['data']
             else:
